@@ -22,6 +22,10 @@ public enum UIOperationsId {
 	SDMXTemplateExport("SDMX Template Export"),
 	JSONImport("JSON Import"),	
   	JSONExport("JSON Export"),
+  	ExcelImport("Excel Import"),	
+  	ExcelExport("Excel Export"),	
+  	ExcelTemplateImport("Excel Generic Import"),	
+  	ExcelTemplateExport("Excel Generic Export"),	
   	ChangeTableType("Change Table Type"), 
 	DeleteColumn("Delete Column"), 
 	AddColumn("Add Column"),
